Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(449)

Unified Diff: src/ia32/jump-target-ia32.cc

Issue 100156: Unbreak IA32 generated code coverage. (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« src/ia32/codegen-ia32.cc ('K') | « src/ia32/codegen-ia32.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ia32/jump-target-ia32.cc
===================================================================
--- src/ia32/jump-target-ia32.cc (revision 1807)
+++ src/ia32/jump-target-ia32.cc (working copy)
@@ -115,11 +115,13 @@
__ bind(&original_fall_through);
} else {
// Forward branch. A copy of the current frame is added to the end
// of the list of frames reaching the target block and a branch to
// the merge code is emitted.
AddReachingFrame(new VirtualFrame(cgen_->frame()));
- __ j(cc, &merge_labels_.last(), hint);
+ masm_->j(cc, &merge_labels_.last(), hint);
is_linked_ = true;
}
}
@@ -115,11 +115,13 @@
__ bind(&original_fall_through);
} else {
- // Forward branch. A copy of the current frame is added to the end
- // of the list of frames reaching the target block and a branch to
- // the merge code is emitted.
+ // Forward branch. A copy of the current frame is added to the end of the
+ // list of frames reaching the target block and a branch to the merge code
+ // is emitted. Use masm_-> instead of __ as forward branches are expected
+ // to be a fixed size (no inserted coverage-checking instructions please).
+ // This is used in Reference::GetValue.
AddReachingFrame(new VirtualFrame(cgen_->frame()));
« src/ia32/codegen-ia32.cc ('K') | « src/ia32/codegen-ia32.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698